@@ -19,7 +19,7 @@ use Plack::Util::Accessor qw/ default_rate rules cache file _match greylist retr
 use Ref::Util             qw/ is_plain_arrayref is_coderef /;
 use Time::Seconds         qw/ ONE_MINUTE /;
 
-our $VERSION = 'v0.7.0';
+our $VERSION = 'v0.7.1';
 
 
 sub prepare_app {
@@ -30,7 +30,7 @@ sub prepare_app {
     die "default_rate must be a positive integer" unless $self->default_rate =~ /^[1-9][0-9]*$/;
 
     my $config = $self->cache_config;
-    $self->cache_config($config) unless defined $config;
+    $self->cache_config( $config //= { } ) unless defined $config;
 
     $config->{init_file}                //= 0;
     $config->{unlink_on_exit}           //= !$config->{init_file};
@@ -204,7 +204,7 @@ Plack::Middleware::Greylist - throttle requests with different rates based on ne
 
 =head1 VERSION
 
-version v0.7.0
+version v0.7.1
 
 =head1 SYNOPSIS
 
